"use strict";

var _ava = _interopRequireDefault(require("ava"));

var _postcss = _interopRequireDefault(require("postcss"));

var _package = require("../../package.json");

var _ = _interopRequireDefault(require("../"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function getWarnings(filters) {
  return (0, _postcss["default"])(filters).process('h1{}').warnings();
}

var fontWeight = _postcss["default"].plugin('fontWeight', function () {
  return function (css) {
    css.walkDecls('font-weight', function (decl) {
      var value = decl.value;
      decl.value = value === 'normal' ? '400' : value === 'bold' ? '700' : value;
    });
  };
});

(0, _ava["default"])('readme example code', function (t) {
  var counter = _postcss["default"].plugin('counter', function () {
    return function (css) {
      css.walkDecls('foo', function (decl) {
        var value = parseInt(decl.value, 10);
        value += 1;
        decl.value = String(value);
      });
    };
  });

  var css = 'h1 { foo: 1 }';
  var out = (0, _postcss["default"])([(0, _["default"])(), counter(), counter()]).process(css).css;
  t.is(out, 'h1 { foo: 2 }');
});
(0, _ava["default"])('should handle processors without the postcssPlugin property', function (t) {
  var foo = function foo() {
    return function (css) {
      return css.walkDecls('foo', function (f) {
        return f.remove();
      });
    };
  };

  var css = 'h1 { foo: bar; font-weight: normal }';
  return (0, _postcss["default"])([foo(), fontWeight(), (0, _["default"])(), foo(), fontWeight()]).process(css).then(function (result) {
    t.is(result.css, 'h1 { font-weight: 400 }');
    t.is(result.processor.plugins.length, 4);
  });
});
(0, _ava["default"])('should warn if plugin exists', function (t) {
  var plugins = [fontWeight(), (0, _["default"])(), fontWeight()];
  var warnings = getWarnings(plugins);
  t.is(warnings.length, 1);
  t.is(warnings[0].text, 'Found duplicate plugin: fontWeight');
});
(0, _ava["default"])('should warn if plugin exists, with a custom message', function (t) {
  var template = function template(_ref) {
    var postcssPlugin = _ref.postcssPlugin;
    return "Uh-oh: ".concat(postcssPlugin);
  };

  var plugins = [fontWeight(), (0, _["default"])({
    template: template
  }), fontWeight()];
  var warnings = getWarnings(plugins);
  t.is(warnings.length, 1);
  t.is(warnings[0].text, 'Uh-oh: fontWeight');
});
(0, _ava["default"])('should not warn when silent', function (t) {
  var plugins = [fontWeight(), (0, _["default"])({
    silent: true
  }), fontWeight()];
  t.is(getWarnings(plugins).length, 0);
});
(0, _ava["default"])('should not warn if the plugin is excluded from the filter', function (t) {
  var plugins = [fontWeight(), (0, _["default"])({
    exclude: ['fontWeight']
  }), fontWeight()];
  t.is(getWarnings(plugins).length, 0);
});
(0, _ava["default"])('should operate forward from the filter instance', function (t) {
  var plugins = [fontWeight(), (0, _["default"])({
    direction: 'forward'
  }), fontWeight(), fontWeight()];
  t.is(getWarnings(plugins).length, 1);
});
(0, _ava["default"])('should operate backward from the filter instance', function (t) {
  var plugins = [fontWeight(), fontWeight(), (0, _["default"])({
    direction: 'backward'
  }), fontWeight()];
  t.is(getWarnings(plugins).length, 1);
});
(0, _ava["default"])('should not filter itself when there are multiple instances', function (t) {
  var plugins = [(0, _["default"])(), (0, _["default"])(), (0, _["default"])(), (0, _["default"])()];
  t.falsy(getWarnings(plugins).length);
});
(0, _ava["default"])('should use the postcss plugin api', function (t) {
  t.truthy((0, _["default"])().postcssVersion, 'should be able to access version');
  t.deepEqual((0, _["default"])().postcssPlugin, _package.name, 'should be able to access name');
});